@@ -1,15 +1,36 @@
-import numpy as np
-from matplotlib import pyplot as plt
-from mpl_toolkits.mplot3d import Axes3D
-from matplotlib import cm
+"""
+Copyright (c) 2014 Rebecca R. Murphy
+All rights reserved.
+
+Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
+
+1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
+
+2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
+
+3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
+
+THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
+"""
+
+
 import os
 import sys
 import struct
-import matplotlib
-from matplotlib.ticker import NullFormatter
-from scipy.optimize import curve_fit
 import csv
 
+try:
+    import numpy as np
+    from matplotlib import pyplot as plt
+    from mpl_toolkits.mplot3d import Axes3D
+    from matplotlib import cm
+    import matplotlib
+    from matplotlib.ticker import NullFormatter
+    from scipy.optimize import curve_fit
+except:
+    print "Numerical libraries not present in the system"
+
 class ALEX_data:
 
     """
@@ -330,11 +351,13 @@ def parse_csv(filepath, filelist, delimiter=","):
     * delimiter (default ","): the delimiter between values in a row of the csv file.
 
     This function assumes that each row of your file has the format:
-    "D_D,D_A,A_D,A_A\n" 
+    "D_D,D_A,A_D,A_A" 
 
     If your data does not have this format (for example if you have separate files for donor and acceptor data), this function will not work well for you.
     
+
     """
+
     D_D = []
     D_A = []
     A_D = []
